function sfun_pendelanim(block)
  % S-Funktion für die Animation eines Fadenpendels
  % Eingang: phi-Koordinate des Pendels
  setup(block);
end
  
%% -------------------------------------------------------------------
function setup(block)
  % Zahl der Anschlüsse
  block.NumInputPorts  = 1;
  block.NumOutputPorts = 0;
  block.NumDialogPrms = 0;

  block.SetPreCompInpPortInfoToDynamic;  % Datentyp übernehmen
  block.SampleTimes = [-1 0];            % Samplezeit übernehmen

  block.RegBlockMethod('Start', @Start);
  block.RegBlockMethod('Update', @Update);
end

%% -------------------------------------------------------------------
function Start(block)
  % erzeugt die Figur incl. Zeichenobjekten 
  initFrame('Pendel-Animation');
  lim = 1.2;
  plot([lim lim -lim -lim lim], [-lim lim lim -lim -lim], 'k-')
  set(gca, 'XTickMode', 'manual', 'YTickMode', 'manual');   
  axis([-lim lim -lim lim]);
  hold on;
  
  % Halterung, fix
  sH = 0.05;
  plot([sH sH -sH -sH sH], [-sH sH sH -sH -sH]);
  
  % Faden
  hFaden = plot([0 0], [0 -1]);
  set(hFaden, 'Tag', 'Faden');
  
  % Kugel
  [xK yK] = computeCircle();
  hKugel = patch(xK, yK - 1, [0 0 0]);
  set(hKugel, 'Tag', 'Kugel');   
end

%% -------------------------------------------------------------------
function Update(block)
  % Werte der Handle holen
  hFaden = findobj('Tag', 'Faden');
  hKugel = findobj('Tag', 'Kugel');
  
  % neue Position berechnen
  phi = block.InputPort(1).Data;
  x = sin(phi);
  y = -cos(phi);
  
  set(hFaden,'XData', [0 x]);
  set(hFaden,'YData', [0 y]);

  [xK, yK] = computeCircle();
  set(hKugel,'XData', xK + x);
  set(hKugel,'YData', yK + y);

  drawnow;
end

%% -------------------------------------------------------------------
function hFigur = initFrame(name)
  % erzeuge Figur, falls nötig
  
  hFigur = findobj('Type','figure', 'Name', name)';
  if isempty(hFigur)
    hFigur = figure('Name', name, 'NumberTitle','off', 'MenuBar', 'none');

    % setze Größe, aber lasse die aktuelle Position auf dem Schirm
    position = get(hFigur, 'Position');
    position(3:4) = [300 300];
    set(hFigur, 'Position', position);
  
    % positioniere Achsen innerhalb der Figur (großer Rand soll weg)
    axes('Position',[0.05 0.05 0.9 0.9]);
  else
    figure(hFigur)           % bringe Figur nach vorne
  end

  cla reset;       % wichtig bei Restart der Simulation
  axis off;
end

%% -------------------------------------------------------------------
function [xK yK] = computeCircle()
  % berechnet Basiskoordinaten für die Pendelkugel
  r = 0.1;
  N = 24;     % Zahl der Ecken
  t = 0:2*pi/N:2*pi;
  xK = r*cos(t);
  yK = r*sin(t);
end
